@@ -10,9 +10,9 @@ from pyrig.dev.artifacts.builder.base.base import Builder
 from pyrig.dev.cli.subcommands import build, protect_repo
 from pyrig.dev.configs.base.base import YamlConfigFile
 from pyrig.dev.configs.pyproject import PyprojectConfigFile
-from pyrig.utils.modules.package import get_src_package
-from pyrig.utils.project.poetry.poetry import get_poetry_run_pyrig_cli_cmd_script
-from pyrig.utils.string import (
+from pyrig.src.modules.package import get_src_package
+from pyrig.src.project.poetry.poetry import get_poetry_run_pyrig_cli_cmd_script
+from pyrig.src.string import (
     make_name_from_obj,
     split_on_uppercase,
 )
@@ -451,15 +451,15 @@ class Workflow(YamlConfigFile):
         )
 
     @classmethod
-    def step_no_build_script(
+    def step_no_builder_defined(
         cls,
         *,
         step: dict[str, Any] | None = None,
     ) -> dict[str, Any]:
         """Get the no build script step."""
         return cls.get_step(
-            step_func=cls.step_no_build_script,
-            run="echo 'No build script found. Skipping build.'",
+            step_func=cls.step_no_builder_defined,
+            run="echo 'No non-abstract builders defined. Skipping build.'",
             step=step,
         )
 
